@@ -1228,6 +1228,17 @@ src_watch_current ()
     return rv;
 }
 
+static gboolean
+src_unwatch_all ()
+{
+    srl_unwatch_all_objects ();
+    if (src_use_speech)
+    {
+	src_say_message (_("unwatch all objects"));
+    }
+    return TRUE;
+}
+
 static gboolean
 src_nav_caret ()
 {
@@ -3013,6 +3024,7 @@ static struct
 
 	{"attributes at caret", 	src_caret_attributes	 	},
 	{"watch current object", 	src_watch_current	 	},
+	{"unwatch all objects", 	src_unwatch_all	 		},
 
 	{"window hierarchy",		src_hierarchy_logic		},
 	{"window hierarchy flat",	src_hierarchy_flat		},
@@ -3477,7 +3489,7 @@ src_ctrl_position_sensor_action_logic (gint index)
     if (!src_crt_sro)
 	return;
 	
-    src_text_index = index - 4 >= 0 ? index - 4 : 0;
+    src_text_index = index >= 0 ? index : 0;
 
     switch (src_braille_position_sensor)
     {
@@ -3551,7 +3563,7 @@ src_ctrl_optical_sensor_action_logic (gint index)
     if (!src_crt_sro)
 	return;
 
-    src_text_index = index - 4 >= 0 ? index - 4 : 0;
+    src_text_index = index >= 0 ? index : 0;
 
     switch (src_braille_optical_sensor)
     {
