@@ -114,7 +114,7 @@ src_present_real_sro (SRObject *obj)
 	gchar *txt;
 	
 	src_enable_format_string = FALSE; 
-    	txt = src_presentation_present_sro_for_device (obj, reason, "braille");
+    	txt = src_presentation_sro_get_pres_for_device (obj, reason, "braille");
 	if (txt)
 	{
 	    gchar *tmp;
@@ -236,13 +236,16 @@ src_present_real_sro (SRObject *obj)
 		    g_free (src_last_key_echo);
 		    src_last_key_echo = NULL;
 		}
-		txt = src_presentation_present_sro_for_device (obj, reason, "speech");
+		txt = src_presentation_sro_get_pres_for_device (obj, reason, "speech");
     		if (txt && txt[0])
     		{
 		    SRObjectRoles role;
 		    sro_get_role (obj, &role, SR_INDEX_CONTAINER);
-		    if (role == SR_ROLE_STATUS_BAR && strcmp (reason , "focus:") == 0)
+		    if ( role == SR_ROLE_STATUS_BAR && strcmp (reason , "focus:") == 0)
 			src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_SYSTEM, FALSE);
+		    else if ((role == SR_ROLE_TABLE || role == SR_ROLE_TREE_TABLE) &&
+				strcmp (reason , "focus:") == 0)
+			src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_IDLE, FALSE);
 		    else
 			src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_IDLE, TRUE);
 		}
@@ -255,7 +258,7 @@ src_present_real_sro (SRObject *obj)
     if (src_use_magnifier)
     {
 	gchar *txt;
-	txt = src_presentation_present_sro_for_device (obj, reason, "magnifier");
+	txt = src_presentation_sro_get_pres_for_device (obj, reason, "magnifier");
 	if (txt)
 	{
 /*	    fprintf (stderr, "\n(%s %d) txt = %s",
@@ -310,7 +313,7 @@ src_present_crt_window ()
     	gchar *txt;
 
 	src_enable_format_string = FALSE; 
-	txt = src_presentation_present_sro_for_device (src_crt_window, reason, "speech");
+	txt = src_presentation_sro_get_pres_for_device (src_crt_window, reason, "speech");
     	if (txt && txt[0])
     	{
 	    if (strcmp (reason, "window:create") == 0)
@@ -339,7 +342,7 @@ src_present_crt_tooltip ()
     	gchar *txt;
 
 	src_enable_format_string = FALSE; 
-	txt = src_presentation_present_sro_for_device (src_crt_tooltip, reason, "speech");
+	txt = src_presentation_sro_get_pres_for_device (src_crt_tooltip, reason, "speech");
     	if (txt && txt[0])
     	{
 	    src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_SYSTEM, TRUE);
@@ -2658,6 +2661,7 @@ src_init(const gchar *mouse_tracking,
     gchar *message = _("Welcome to Gnopernicus");
     gboolean brl_error = FALSE;
     gboolean initialize_finished = FALSE;
+    gboolean default_invert_value;
 
     /* initialize SR Utils */
     sru_init();
@@ -2684,7 +2688,18 @@ src_init(const gchar *mouse_tracking,
     /* initialize Speech */
     if (src_use_speech)
 	src_use_speech = src_speech_init ();
-
+    
+    /* check if invert is true */
+    if (!invert)
+    {
+	default_invert_value = DEFAULT_MAGNIFIER_INVERT;
+	srconf_get_data_with_default (MAGNIFIER_INVERT,
+				      CFGT_BOOL,
+				      (gpointer)&invert,
+				      (gpointer)&default_invert_value,
+				      MAGNIFIER_CONFIG_PATH);
+    }
+    
     /* set the command lines arguments in gconf */
     src_set_command_lines (mouse_tracking,
 		    	    focus_tracking,
